@@ -1,17 +1,16 @@
-C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
-C* Copyright by The HDF Group.                                               *
-C* Copyright by the Board of Trustees of the University of Illinois.         *
-C* All rights reserved.                                                      *
-C*                                                                           *
-C* This file is part of HDF.  The full HDF copyright notice, including       *
-C* terms governing use, modification, and redistribution, is contained in    *
-C* the files COPYING and Copyright.html.  COPYING can be found at the root   *
-C* of the source code distribution tree; Copyright.html can be found at      *
-C* http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
-C* access to either file, you may request a copy from help@hdfgroup.org.     *
-C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+C * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+C  Copyright by The HDF Group.                                               *
+C  Copyright by the Board of Trustees of the University of Illinois.         *
+C  All rights reserved.                                                      *
+C                                                                            *
+C  This file is part of HDF.  The full HDF copyright notice, including       *
+C  terms governing use, modification, and redistribution, is contained in    *
+C  the COPYING file, which can be found at the root of the source code       *
+C  distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+C  If you do not have access to either file, you may request a copy from     *
+C  help@hdfgroup.org.                                                        *
+C * * * * * * * * *  * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 C
-C $Id: manf.f 4932 2007-09-07 17:17:23Z bmribler $
 C
       subroutine manf (number_failed)
 C
@@ -32,23 +31,14 @@ C
       character*20 myname
       parameter (myname = 'manf')
 
-      integer afstart, afend, afcreate, affcreate
-      integer afwriteann, afendaccess, hopen, hclose
-
-      integer dssdims, dsadata, dslref, dsgdims
-      integer d8aimg, DFR8lastref, d8gimg
-
       integer numberfailed, ISFIRST, NOTFIRST, MAXLENLAB
       integer MAXLEN_DESC, ROWS, COLS, REPS
-      integer DFTAG_SDG, DFTAG_RIG
 
-      parameter ( ISFIRST =        1, 
-     *            NOTFIRST =       0, 
+      parameter ( ISFIRST =        1,
+     *            NOTFIRST =       0,
      *            MAXLENLAB =    30,
-     *            MAXLEN_DESC =  500, 
-     *            DFTAG_SDG   =  700,
-     *            DFTAG_RIG   =  306,
-     *            ROWS =          10, 
+     *            MAXLEN_DESC =  500,
+     *            ROWS =          10,
      *            COLS =          10,
      *            REPS =           2 )
 
@@ -57,10 +47,8 @@ C
       integer rank
       integer j, dimsizes(2)
       integer fhandle, anhandle, ahandle
-      integer  DFACC_CREATE, DFACC_READ
-      integer AN_DATA_LABEL, AN_DATA_DESC, AN_FILE_LABEL, AN_FILE_DESC
 
-      character*30 labsds, labsds2 
+      character*30 labsds, labsds2
       character*30 labris, labris2
       character*500 descsds, descsds2
       character*500 descris, descris2
@@ -78,12 +66,6 @@ C
       number_failed = 0
       numberfailed =  0
       CR = char(10)
-      DFACC_CREATE = 4
-      DFACC_READ   = 1
-      AN_DATA_LABEL = 0
-      AN_DATA_DESC  = 1
-      AN_FILE_LABEL = 2
-      AN_FILE_DESC  = 3
       TESTFILE = 'manf.hdf'
 
 C *** set up file labels and descriptions ***
@@ -98,10 +80,10 @@ C *** set up object labels and descriptions ***
       labsds2 = 'Object label #1: sds2'
       labris  = 'Object label #2: image'
       labris2 = 'Object label #2: image2'
-      descsds = 'Object Descr #1: 1  2  3  4  5  6  7  8  9 10 11 12 ' 
+      descsds = 'Object Descr #1: 1  2  3  4  5  6  7  8  9 10 11 12 '
      *          // CR // '                13 14 15 16 17 18 19 20 '
      *          // ' **END SDS DESCR**'
-      descsds2 = 'Object Descr #1: 1  2  3  4  5  6  7  8  9 10 11 12 ' 
+      descsds2 = 'Object Descr #1: 1  2  3  4  5  6  7  8  9 10 11 12 '
      *          // CR // '                13 14 15 16 17 18 19 20 '
      *          // ' **END SDS2 DESCR**'
       descris = 'Object Descr #2: A B C D E F G H I J K L '
@@ -110,9 +92,9 @@ C *** set up object labels and descriptions ***
      *          // CR // '                M N O **END IMAGE2 DESCR **'
 
 C  *** generate float array and image ***
- 
+
       rank = 2
-      dimsizes(1)=ROWS 
+      dimsizes(1)=ROWS
       dimsizes(2)=COLS
 
       call gen2Dfloat(ROWS, COLS, data)
@@ -168,12 +150,12 @@ C  ***  Write data labels and descriptions ***
      +    '***  Writing labels & descriptions with SDS and RIS ***')
 
       do 100 j=1,REPS
-C  ***  write out scientific data set 
+C  ***  write out scientific data set
          ret = dsadata(TESTFILE, rank,dimsizes, data)
          call VRFY(ret, 'dsadata', number_failed)
 
-C ****    write out annotations for 2 out of every 3 
-         if (mod(j,3) .ne. 0) then 
+C ****    write out annotations for 2 out of every 3
+         if (mod(j,3) .ne. 0) then
             refnum = dslref()
 
 C ********** Write out 2 labels for each SDS *****************
@@ -193,7 +175,7 @@ C ********** Write out 2 labels for each SDS *****************
             ret = afendaccess(anhandle)
             call VRFY(ret, 'afendaccess', number_failed)
 
-C *********** Write out 2 descritptions for each SDS ***********
+C *********** Write out 2 descriptions for each SDS ***********
             anhandle = afcreate(ahandle,DFTAG_SDG,refnum,AN_DATA_DESC)
             ret = anhandle
             call VRFY(ret, 'afcreate', number_failed)
@@ -233,7 +215,7 @@ C ********** Write out 2 labels for each Image *****************
           ret = afendaccess(anhandle)
           call VRFY(ret, 'afendaccess', number_failed)
 
-C *********** Write out 2 descritptions for each Image ***********
+C *********** Write out 2 descriptions for each Image ***********
           anhandle = afcreate(ahandle, DFTAG_RIG, refnum, AN_DATA_DESC)
           ret = anhandle
           call VRFY(ret, 'afcreate', number_failed)
@@ -268,12 +250,12 @@ C********  Read data labels and descriptions *********
           call VRFY(ret, 'dsgdims', number_failed)
           refnum = dslref()
 
-C ******  read in annotations for 2 out of every 3 
+C ******  read in annotations for 2 out of every 3
           if (mod(j,3) .ne. 0) then
-              call man_check_lab_desc(TESTFILE, DFTAG_SDG, refnum, 
+              call man_check_lab_desc(TESTFILE, DFTAG_SDG, refnum,
      *                            labsds, descsds, numberfailed)
 
-              call man_check_lab_desc(TESTFILE, DFTAG_SDG, refnum, 
+              call man_check_lab_desc(TESTFILE, DFTAG_SDG, refnum,
      *                            labsds2, descsds2, numberfailed)
           endif
 
@@ -281,12 +263,12 @@ C ****    read annotations for images
           ret = d8gimg(TESTFILE, newimage, COLS, ROWS, pal)
           call VRFY(ret, 'd8gimg', number_failed)
           refnum = DFR8lastref()
-          call man_check_lab_desc(TESTFILE, DFTAG_RIG, refnum, 
+          call man_check_lab_desc(TESTFILE, DFTAG_RIG, refnum,
      *                        labris, descris, numberfailed)
 
-          call man_check_lab_desc(TESTFILE, DFTAG_RIG, refnum, 
+          call man_check_lab_desc(TESTFILE, DFTAG_RIG, refnum,
      *                        labris2, descris2, numberfailed)
-      
+
   200 continue
 
 C ****** Check file labels/descriptions *******
@@ -313,7 +295,7 @@ C  man_check_lab_desc:  read and compare label and description
 C                   with expected ones
 C
 C**************************************************************
-      subroutine man_check_lab_desc(fname, tag, ref, label, desc, 
+      subroutine man_check_lab_desc(fname, tag, ref, label, desc,
      *                          num_failed)
       implicit none
       include 'fortest.inc'
@@ -328,10 +310,6 @@ C**************************************************************
       parameter (ERR_FILE = 'Fortran_err.dat')
 
       integer  inlablen, indesclen, ret
-
-      integer affileinfo, afnumann, afannlist, afannlen
-      integer afreadann, afstart, afend, afendaccess, hopen, hclose
-      integer hishdff, hestringf, heprntf
       character*80 error_message
 
       integer fileh, anh
@@ -341,14 +319,7 @@ C**************************************************************
       integer dlabels(2), ddescs(2)
       character*30   inlabel, fannlabel
       character*500 indesc, fanndesc
-      integer AN_DATA_LABEL, AN_DATA_DESC, AN_FILE_LABEL, AN_FILE_DESC
-      integer DFACC_READ
       integer error_code
-      DFACC_READ = 1
-      AN_DATA_LABEL = 0
-      AN_DATA_DESC  = 1
-      AN_FILE_LABEL = 2
-      AN_FILE_DESC  = 3
       error_code = 0
 
 C ***** Test if the file fname is an HDF file
@@ -372,7 +343,7 @@ C
 1111  continue
 C
 C     Call hishdff with  file not being an hdf file. Call should return
-C     0 
+C     0
 C
       ret = hishdff('manf.f')
       if (ret .ne. 0) then
@@ -443,7 +414,7 @@ C ****** Check if we found label in list *****
          num_failed = num_failed + 1
       endif
 
-C ***** look for description in list 
+C ***** look for description in list
       found = 0
       fannlen = 0
       fanndesc = ' '
@@ -465,17 +436,17 @@ C ***** look for description in list
   400 continue
 
       if (indesclen .ne. len(desc)) then
-          print *,'   >>>BAD DESCRIPTION LENGTH.' 
-          print *,'                        IS: ', indesclen 
-          print *,'                 SHOULD BE: ', len(desc) 
-          num_failed = num_failed + 1 
+          print *,'   >>>BAD DESCRIPTION LENGTH.'
+          print *,'                        IS: ', indesclen
+          print *,'                 SHOULD BE: ', len(desc)
+          num_failed = num_failed + 1
        endif
 
        if (fanndesc .ne. desc) then
-          print *,'   >>>BAD DESCRIPTION.' 
-          print *,'                        IS: ', fanndesc 
-          print *,'                 SHOULD BE: ', desc 
-          num_failed = num_failed + 1 
+          print *,'   >>>BAD DESCRIPTION.'
+          print *,'                        IS: ', fanndesc
+          print *,'                 SHOULD BE: ', desc
+          num_failed = num_failed + 1
        endif
 
 C ****** close file *******
@@ -507,22 +478,12 @@ C************************************************************
       parameter ( MAXLENFLAB =    35,
      *            MAXLEN_FDESC =  100 )
 
-      integer affileinfo, afselect, afannlen, afreadann
-      integer afstart, afend, afendaccess, hopen, hclose
-
       integer ret
       integer fileh, annh, anh
       integer nflabs, nfdescs, nolabs, nodescs
       integer fannlen
       character*35 flabel
       character*100 fdesc
-      integer AN_DATA_LABEL, AN_DATA_DESC, AN_FILE_LABEL, AN_FILE_DESC
-      integer DFACC_READ
-      DFACC_READ = 1
-      AN_DATA_LABEL = 0
-      AN_DATA_DESC  = 1
-      AN_FILE_LABEL = 2
-      AN_FILE_DESC  = 3
 
 C **** We check both file label/description
       fileh = hopen(fname, DFACC_READ,0)
@@ -574,17 +535,17 @@ C **** Read file description *****
       call VRFY(ret, 'afendaccess', num_failed)
 
       if (fannlen .ne. len(desc)) then
-          print *,'   >>>BAD DESCRIPTION LENGTH.' 
-          print *,'                        IS: ', fannlen 
-          print *,'                 SHOULD BE: ', len(desc) 
-          num_failed = num_failed + 1 
+          print *,'   >>>BAD DESCRIPTION LENGTH.'
+          print *,'                        IS: ', fannlen
+          print *,'                 SHOULD BE: ', len(desc)
+          num_failed = num_failed + 1
        endif
 
        if (fdesc .ne. desc) then
-          print *,'   >>>BAD DESCRIPTION.' 
-          print *,'                        IS: ', fdesc 
-          print *,'                 SHOULD BE: ', desc 
-          num_failed = num_failed + 1 
+          print *,'   >>>BAD DESCRIPTION.'
+          print *,'                        IS: ', fdesc
+          print *,'                 SHOULD BE: ', desc
+          num_failed = num_failed + 1
        endif
 
 C ****** close file *******
